import { waitUntil, enhanceError, compareNumbers, numberError, updateElementsArray } from '../../utils.js';
import { refetchElements } from '../../util/refetchElements.js';
export async function toBeElementsArrayOfSize(received, expected, options = {}) {
    const isNot = this.isNot;
    const { expectation = 'elements array of size', verb = 'be' } = this;
    let numberOptions;
    if (typeof expected === 'number') {
        numberOptions = { eq: expected };
    }
    else if (!expected || (typeof expected.eq !== 'number' && typeof expected.gte !== 'number' && typeof expected.lte !== 'number')) {
        throw new Error('Invalid params passed to toBeElementsArrayOfSize.');
    }
    else {
        numberOptions = expected;
    }
    let elements = await received;
    const arrLength = elements.length;
    const pass = await waitUntil(async () => {
        elements = await refetchElements(elements, numberOptions.wait, true);
        return compareNumbers(elements.length, numberOptions);
    }, isNot, { ...numberOptions, ...options });
    updateElementsArray(pass, received, elements, true);
    const error = numberError(numberOptions);
    const message = enhanceError(elements, error, arrLength, this, verb, expectation, '', numberOptions);
    return {
        pass,
        message: () => message
    };
}
